@@ -1,6 +1,7 @@
 import yaml
 import logging
 import logging.config
+from aiharness import xml2object
 
 try:
     from yaml import CLoader as Loader, CDumper as Dumper
@@ -8,7 +9,7 @@ except ImportError:
     from yaml import Loader, Dumper
 
 
-def load_config(file: str):
+def load_yaml(file: str):
     try:
         with open(file, 'r') as stream:
             return yaml.load(stream=stream, Loader=Loader)
@@ -17,7 +18,7 @@ def load_config(file: str):
         return None
 
 
-conf = load_config('logging.yaml')
+conf = load_yaml('logging.yaml')
 if conf is not None:
     logging.config.dictConfig(conf)
 
@@ -30,3 +31,12 @@ def getRootLogger():
     return logging.getLogger('root')
 
 
+log = getRootLogger()
+
+
+def load_xml(xml_file):
+    try:
+        return xml2object.parse(xml_file)
+    except Exception as e:
+        log.error(e)
+    return None
